@@ -48,7 +48,7 @@ def add_alarm_status(
         print(new_alarm_status)
     """
     alarm_status_input = AddAlarmStatusInput(name=name)
-    if (len(name) != 0):
+    if alarm_status_input.name =="":
         result = addAlarmStatus.execute(client, input=alarm_status_input)
         return alarmStatus(name=result.name, id=result.id)
     else:
